# tsgen

[![CI/CD Status](https://github.com/MarwanDebbiche/tsgen/workflows/CI%2FCD/badge.svg?branch=master)](https://github.com/MarwanDebbiche/tsgen/actions?query=branch:master)
[![Coverage Status](https://coveralls.io/repos/github/MarwanDebbiche/tsgen/badge.svg?branch=master)](https://coveralls.io/github/MarwanDebbiche/tsgen?branch=master)
[![Latest Version](https://img.shields.io/pypi/v/tsgen.svg?color=blue)](https://pypi.python.org/pypi/tsgen)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/tsgen?label=pypi%20downloads)](https://pypi.org/project/tsgen/)
![License](https://img.shields.io/github/license/MarwanDebbiche/tsgen)

tsgen (for Time Series Generator) is a package developed for educational purposes that helps create unidimensional time series of different shapes.

## Installation

You can install tsgen from PyPI using pip:

```
pip install tsgen
```

## Getting started

![Getting Started](./images/getting_started.png)

<!-- See the [documentation]() for more details. -->
